buckerize

Function buckerize 

pub fn buckerize<I>(
    tracks: I,
    overlap_type: OverlapType,
) -> Map<String, Vec<Vec<GenePred>>>
where I: IntoIterator<Item = (String, Vec<GenePred>)>,
Groups overlapping transcripts into buckets using Union-Find.

tracks must already be grouped by chrom:strand, for example chr1:+ or chr1:-. In CDS mode this function uses coding exons when present and falls back to the transcript span when a record has no coding intervals.